/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.conf;

import java.io.*;
import com.silverwrist.venice.core.TopicMessageContext;
import com.silverwrist.venice.except.*;
import com.silverwrist.venice.ui.ContentExecute;
import com.silverwrist.venice.ui.LinkTypes;
import com.silverwrist.venice.ui.RequestExec;
import com.silverwrist.venice.ui.helpers.ThrowableContent;

public class AttachmentContent extends ThrowableContent implements ContentExecute
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String type;
  private String filename;
  private int length;
  private InputStream stm;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public AttachmentContent(TopicMessageContext msg) throws AccessError, DataException
  {
    super();
    this.type = msg.getAttachmentType();
    this.filename = msg.getAttachmentFilename();
    this.length = msg.getAttachmentLength();
    this.stm = msg.getAttachmentData();

  } // end constructor

  public AttachmentContent(String data, String type, String filename)
  {
    super();
    this.type = type;
    this.filename = filename;
    try
    { // get the string data and output it
      byte[] d = data.getBytes("UTF-8");
      this.length = d.length;
      this.stm = new ByteArrayInputStream(d);

    } // end try
    catch (UnsupportedEncodingException e)
    { // this is not supposed to happen
      throw new InternalStateError("encoding not found?!?!?!?");

    } // end catch

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface ContentExecute
   *--------------------------------------------------------------------------------
   */

  public void execute(RequestExec req) throws IOException
  {
    req.sendBinary(type,filename,length,stm);

  } // end execute

} // end class BinaryDataContent
